@@ -5,4 +5,5 @@
      文件名 : __init__.py.py
      邮箱: 1641143982@qq.com
 """
-import testneo
\ No newline at end of file
+
+from testneo.log import *
